Colour - TODO
=============

TODO
----

-   colour/__init__.py

    -   Line 291 : # TODO: Remove legacy printing support when deemed appropriate.


-   colour/colorimetry/spectrum.py

    -   Line 1112 : # TODO: Provide support for fractional interval like 0.1, etc...


-   colour/colorimetry/tristimulus.py

    -   Line 765 : # TODO: Investigate code vectorisation.


-   colour/colorimetry/tests/test_spectrum.py

    -   Line 1440 : # TODO: Remove statement whenever we make "Scipy" 0.19.0 the minimum version. Skipping tests because of "Scipy" 0.19.0 interpolation code changes.
    -   Line 1640 : # TODO: Remove statement whenever we make "Scipy" 0.19.0 the minimum version. Skipping tests because of "Scipy" 0.19.0 interpolation code changes.


-   colour/appearance/ciecam02.py

    -   Line 288 : # TODO: Compute hue composition.


-   colour/appearance/cam16.py

    -   Line 282 : # TODO: Compute hue composition.


-   colour/appearance/hunt.py

    -   Line 420 : # TODO: Implement hue quadrature & composition computation.
    -   Line 451 : # TODO: Implement whiteness-blackness :math:`Q_{wb}` computation.


-   colour/appearance/rlab.py

    -   Line 265 : # TODO: Implement hue composition computation.


-   colour/appearance/nayatani95.py

    -   Line 267 : # TODO: Implement hue quadrature & composition computation.
    -   Line 279 : # TODO: Investigate components usage. M_RG, M_YB = tsplit(colourfulness_components(C_RG, C_YB, brightness_ideal_white))


-   colour/appearance/llab.py

    -   Line 325 : # TODO: Implement hue composition computation.


-   colour/appearance/tests/test_cam16.py

    -   Line 37 : # TODO: The current fixture data is generated from direct computations using our model implementation. We have asked ground truth data to Li et al. (2016) and will update the "cam16.csv" file accordingly whenever we receive it.


-   colour/io/luts/lut.py

    -   Line 126 : # TODO: Re-enable when dropping Python 2.7. pylint: disable=E1121


-   colour/models/rgb/derivation.py

    -   Line 217 : # TODO: Investigate if we return an ndarray here with primaries and whitepoint stacked together.


-   colour/models/rgb/rgb_colourspace.py

    -   Line 540 : # TODO: Revisit for potential behaviour / type checking.
    -   Line 573 : # TODO: Revisit for potential behaviour / type checking.


-   colour/models/rgb/tests/test_derivation.py

    -   Line 280 : # TODO: Simplify that monster.


-   colour/utilities/array.py

    -   Line 183 : # TODO: Change to "DEFAULT_INT_DTYPE" when and if https://github.com/numpy/numpy/issues/11956 is addressed.


-   colour/characterisation/correction.py

    -   Line 225 : # TODO: Generalise polynomial expansion.


-   colour/notation/munsell.py

    -   Line 1056 : # TODO: Consider refactoring implementation.
    -   Line 1407 : # TODO: Should raise KeyError, need to check the tests.


-   colour/notation/tests/test_munsell.py

    -   Line 1355 : # TODO: This test is covered by the previous class, do we need a dedicated one?
    -   Line 1421 : # TODO: This test is covered by the previous class, do we need a dedicated one?


-   colour/continuous/signal.py

    -   Line 380 : # TODO: Check for interpolator capabilities.
    -   Line 445 : # TODO: Check for extrapolator capabilities.
    -   Line 586 : # TODO: Discuss what is the most suitable behaviour, either the following or __str__ one.


-   colour/continuous/multi_signal.py

    -   Line 698 : # TODO: Discuss what is the most suitable behaviour, either the following or __str__ one.
    -   Line 1319 : # TODO: Implement support for Signal class passing.


-   colour/volume/rgb.py

    -   Line 310 : # TODO: Investigate for generator yielding directly a ndarray.


-   colour/algebra/tests/test_interpolation.py

    -   Line 437 : # TODO: Revisit if the interpolator can be applied on non-uniform "x" independent variable.

About
-----

| **Colour** by Colour Developers
| Copyright © 2013-2019 – Colour Developers – `colour-science@googlegroups.com <colour-science@googlegroups.com>`_
| This software is released under terms of New BSD License: http://opensource.org/licenses/BSD-3-Clause
| `http://github.com/colour-science/colour <http://github.com/colour-science/colour>`_
